OpenAI Codex dynamic quota checker.
Fetches https://chatgpt.com/backend-api/wham/usage, selects the
regular Codex bucket (or the nested Codex Spark bucket), then exposes
the 5h and 7d percentage windows as normalized Vis limit rows.
OpenAI Codex dynamic quota checker. Fetches `https://chatgpt.com/backend-api/wham/usage`, selects the regular Codex bucket (or the nested Codex Spark bucket), then exposes the 5h and 7d percentage windows as normalized Vis limit rows.
(dynamic-limits! access-token account-id)(dynamic-limits! access-token account-id model-ref)Fetch and normalize OpenAI Codex dynamic quota data for an access
token/account id pair. Optional model-ref selects the Codex Spark
nested bucket when applicable.
Fetch and normalize OpenAI Codex dynamic quota data for an access token/account id pair. Optional `model-ref` selects the Codex Spark nested bucket when applicable.
(fetch-usage! access-token account-id)Fetch raw ChatGPT/Codex usage JSON from
https://chatgpt.com/backend-api/wham/usage.
Fetch raw ChatGPT/Codex usage JSON from `https://chatgpt.com/backend-api/wham/usage`.
(usage->dynamic-limits usage)(usage->dynamic-limits usage model-ref)(usage->dynamic-limits usage model-ref now-ms)Convert ChatGPT/Codex /wham/usage JSON into Vis dynamic limit rows.
model-ref may be a model id string/keyword or a map with :id /
:name. It is used only for Codex Spark, whose bucket is nested in
additional_rate_limits, matching Codex/ChatGPT's usage payload.
Convert ChatGPT/Codex `/wham/usage` JSON into Vis dynamic limit rows. `model-ref` may be a model id string/keyword or a map with `:id` / `:name`. It is used only for Codex Spark, whose bucket is nested in `additional_rate_limits`, matching Codex/ChatGPT's usage payload.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |